import { OnInit, OnDestroy, TemplateRef, AfterViewInit, ChangeDetectorRef } from "@angular/core";
import { Observable } from "rxjs";
import { TypeaheadDirective } from "../../directives/typeahead/typeahead.directive";
/**
 * Description of css classes that are applied to TypeaheadTagsComponent
 */
export interface TypeaheadTagsCssClasses {
    /**
     * Classes applied to typeahead input
     */
    typeaheadClasses?: {
        [className: string]: true;
    };
    /**
     * Main content div css class
     */
    mainClass?: string;
    /**
     * Tag css class
     */
    tagClass?: string;
    /**
     * Tag content css class
     */
    tagContentClass?: string;
    /**
     * Class for remove button (link)
     */
    removeClass?: string;
}
/**
 * Component that is used for creating autocomplete (typeahead.js) with tags
 */
export declare class TypeaheadTagsComponent implements OnInit, OnDestroy, AfterViewInit {
    private _changeDetector;
    /**
     * Css classes applied to inner elements
     */
    private _cssClasses;
    /**
     * Subject that is used for emitting changes for model binding
     */
    private _externalValueChangeSubject;
    /**
     * Subscription for selection changes
     */
    private _selectionChangesSubscription;
    /**
     * Array of serialized values, used for comparison
     */
    private _serializedValues;
    /**
     * Currently set value
     */
    private _value;
    /**
     * Function that is used for serialization
     */
    serializationFn: (item: any) => string;
    /**
     * Indication whether duplicates are allowed
     */
    allowDuplicates: boolean;
    /**
     * Count of maximal number of values contained in this input
     */
    maxValues: number;
    /**
     * Indication whether item should be removed on backspace
     */
    removeOnBackspace: boolean;
    /**
     * Placeholder for typeahead input
     */
    placeholder: string;
    /**
     * Css classes applied to inner elements
     */
    cssClasses: TypeaheadTagsCssClasses;
    /**
     * Indication that also non existing value from options will be accepted as value, it is always as string value
     */
    freeInput: boolean;
    /**
     * Maximal number of displayed items
     */
    typeaheadMaxItems: number;
    /**
     * Minimal number of characters to start search
     */
    typeaheadMinLength: number;
    /**
     * Name of displayed property as selected value
     */
    typeaheadDisplayedProperty: string | ((suggestion: any) => string) | null;
    /**
     * Name of property that is used for extracting value from object
     */
    typeaheadValueProperty: string | null;
    /**
     * Debounce time that indicates after which time of idle perform search
     */
    typeaheadDebounceTime: number;
    /**
     * Template that is used for suggestion, using handlebar syntax
     */
    typeaheadTemplate: string | null;
    /**
     * Function that is called to obtain data for search
     */
    typeaheadSource: ((query: any) => Observable<any>) | null;
    /**
     * Indication that this component should be tagsDisabled
     */
    tagsDisabled: boolean;
    /**
     * Typeahead directive instance
     */
    typeahead: TypeaheadDirective;
    /**
     * Custom template for tag content
     */
    tagContentTemplate: TemplateRef<any>;
    /**
     * Gets or sets currently set value
     */
    get value(): any[];
    set value(value: any[]);
    /**
     * Gets observable that emits changes of value
     */
    get valueChanged(): Observable<any[]>;
    constructor(_changeDetector: ChangeDetectorRef);
    /**
     * Initialize component
     */
    ngOnInit(): void;
    /**
     * Called when view was initialized
     */
    ngAfterViewInit(): void;
    /**
     * Called when component is destroyed
     */
    ngOnDestroy(): void;
    /**
     * Process confirmation keys
     * @param keyCode - Code of key that was pressed
     */
    handleKeyPress(keyCode: number): void;
    /**
     * Process key down
     * @param event - Event that occured
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Removes tag at specified index
     * @param index - Index of tag to be removed
     */
    removeTag(index: any): void;
    /**
     * Gets displayed value for tag
     * @param value - Tag value that is going to be displayed
     */
    getTagDisplayedValue(value: any): any;
    /**
     * Adds value to control
     * @param value - Value to be added
     */
    private _addValue;
}
//# sourceMappingURL=typeaheadTags.component.d.ts.map